import { NonNullablePaths } from '@wix/sdk-types';
/** The `PlacementStatus` object represents the status of your app's site plugins, indicating whether they are currently placed in a slot on the user's site. */
export interface PlacementStatus {
    /**
     * Plugin ID. This is a unique ID that is assigned to each plugin. You can view your plugin IDs in [extensions](https://dev.wix.com/app-selector?title=Select+an+App&primaryButtonText=Select+Site&actionUrl=https%3A%2F%2Fdev.wix.com%2Fapps%2F%7BappId%7D%2Fextensions) in your app's dashboard.
     * @format GUID
     * @readonly
     */
    pluginId?: string | null;
    /**
     * Whether the plugin placed in a slot on the user's site.
     * @readonly
     */
    placedInSlot?: boolean | null;
}
export interface GetPlacementStatusRequest {
}
export interface GetPlacementStatusResponse {
    /** Data about placement statuses of your app's site plugins on the user's site. */
    placementStatuses?: PlacementStatus[];
}
/**
 * Get the placement statuses of your app's site plugins on the user's site.
 * @public
 * @permissionId PLUGINS.PLACEMENT_STATUSES_READ
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Manage Bookings Services and Settings
 * @permissionScopeId SCOPE.BOOKINGS.CONFIGURATION
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Manage Challenges
 * @permissionScopeId SCOPE.CHALLENGES.MANAGE
 * @permissionScope Manage Portfolio
 * @permissionScopeId SCOPE.PORTFOLIO.MANAGE-PORTFOLIO
 * @permissionScope Access Verticals by Automations
 * @permissionScopeId SCOPE.CRM.ACCESS-VERTICALS-BY-AUTOMATIONS
 * @permissionScope Manage Restaurants - all permissions
 * @permissionScopeId SCOPE.RESTAURANTS.MEGA-SCOPES
 * @permissionScope Set Up Automations
 * @permissionScopeId SCOPE.CRM.SETUP-AUTOMATIONS
 * @permissionScope Read Site Plugin Status
 * @permissionScopeId SCOPE.SITE-PLUGIN.READ-PLACEMENT-STATUS
 * @applicableIdentity APP
 * @fqn wix.app_plugins.site_plugins.v1.PluginsPlacementStatusImpl.GetPlacementStatus
 */
export declare function getPlacementStatus(): Promise<NonNullablePaths<GetPlacementStatusResponse, `placementStatuses`>>;
